@@ -2,7 +2,6 @@ import importlib
 from types import ModuleType
 
 import pytest
-from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 from sqlmodel import create_engine
 from sqlmodel.pool import StaticPool
@@ -549,26 +548,14 @@ def test_tutorial(module: ModuleType):
                         "properties": {
                             "name": {"title": "Name", "type": "string"},
                             "secret_name": {"title": "Secret Name", "type": "string"},
-                            "age": IsDict(
-                                {
-                                    "title": "Age",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Age", "type": "integer"}
-                            ),
-                            "team_id": IsDict(
-                                {
-                                    "title": "Team Id",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Team Id", "type": "integer"}
-                            ),
+                            "age": {
+                                "title": "Age",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
+                            "team_id": {
+                                "title": "Team Id",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
                         },
                     },
                     "HeroPublic": {
@@ -578,26 +565,14 @@ def test_tutorial(module: ModuleType):
                         "properties": {
                             "name": {"title": "Name", "type": "string"},
                             "secret_name": {"title": "Secret Name", "type": "string"},
-                            "age": IsDict(
-                                {
-                                    "title": "Age",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Age", "type": "integer"}
-                            ),
-                            "team_id": IsDict(
-                                {
-                                    "title": "Team Id",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Team Id", "type": "integer"}
-                            ),
+                            "age": {
+                                "title": "Age",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
+                            "team_id": {
+                                "title": "Team Id",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
                             "id": {"title": "Id", "type": "integer"},
                         },
                     },
@@ -608,85 +583,43 @@ def test_tutorial(module: ModuleType):
                         "properties": {
                             "name": {"title": "Name", "type": "string"},
                             "secret_name": {"title": "Secret Name", "type": "string"},
-                            "age": IsDict(
-                                {
-                                    "title": "Age",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Age", "type": "integer"}
-                            ),
-                            "team_id": IsDict(
-                                {
-                                    "title": "Team Id",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Team Id", "type": "integer"}
-                            ),
+                            "age": {
+                                "title": "Age",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
+                            "team_id": {
+                                "title": "Team Id",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
                             "id": {"title": "Id", "type": "integer"},
-                            "team": IsDict(
-                                {
-                                    "anyOf": [
-                                        {"$ref": "#/components/schemas/TeamPublic"},
-                                        {"type": "null"},
-                                    ]
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"$ref": "#/components/schemas/TeamPublic"}
-                            ),
+                            "team": {
+                                "anyOf": [
+                                    {"$ref": "#/components/schemas/TeamPublic"},
+                                    {"type": "null"},
+                                ]
+                            },
                         },
                     },
                     "HeroUpdate": {
                         "title": "HeroUpdate",
                         "type": "object",
                         "properties": {
-                            "name": IsDict(
-                                {
-                                    "title": "Name",
-                                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Name", "type": "string"}
-                            ),
-                            "secret_name": IsDict(
-                                {
-                                    "title": "Secret Name",
-                                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Secret Name", "type": "string"}
-                            ),
-                            "age": IsDict(
-                                {
-                                    "title": "Age",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Age", "type": "integer"}
-                            ),
-                            "team_id": IsDict(
-                                {
-                                    "title": "Team Id",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Team Id", "type": "integer"}
-                            ),
+                            "name": {
+                                "title": "Name",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
+                            "secret_name": {
+                                "title": "Secret Name",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
+                            "age": {
+                                "title": "Age",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
+                            "team_id": {
+                                "title": "Team Id",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
                         },
                     },
                     "TeamCreate": {
@@ -728,36 +661,18 @@ def test_tutorial(module: ModuleType):
                         "title": "TeamUpdate",
                         "type": "object",
                         "properties": {
-                            "id": IsDict(
-                                {
-                                    "title": "Id",
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Id", "type": "integer"}
-                            ),
-                            "name": IsDict(
-                                {
-                                    "title": "Name",
-                                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Name", "type": "string"}
-                            ),
-                            "headquarters": IsDict(
-                                {
-                                    "title": "Headquarters",
-                                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                                }
-                            )
-                            | IsDict(
-                                # TODO: remove when deprecating Pydantic v1
-                                {"title": "Headquarters", "type": "string"}
-                            ),
+                            "id": {
+                                "title": "Id",
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                            },
+                            "name": {
+                                "title": "Name",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
+                            "headquarters": {
+                                "title": "Headquarters",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
                         },
                     },
                     "ValidationError": {
